@@ -421,7 +421,6 @@ class Scratch2Py():
                     x = i['name']
                     if x == ('☁ ' + str(name)):
                         return i['value']
-                return 0 
             except:
                 return 'Sorry, there was an error.'
 
@@ -473,7 +472,6 @@ class Scratch2Py():
                         x = i['name']
                         if x == ('☁ ' + str(name)):
                             return i['value']
-                    return 0 
                 except json.decoder.JSONDecodeError:
                     resp = requests.get("https://clouddata.scratch.mit.edu/logs?projectid=" +
                                 str(self.id)+"&limit="+str(limit)+"&offset=0").json()
@@ -486,9 +484,9 @@ class Scratch2Py():
             data = []
             while True:
                 encodedMethod = self.__readCloudVar('Method')
-                if Method != 0:
+                if Method != None:
                     Method = encoder.decode(encodedMethod)
-                if Method == "set":
+                if encodedMethod == "set":
                     encodedSend = self.__readCloudVar('Send')
                     Send = str(encoder.decode(encodedSend))
                     encodedVal = self.__readCloudVar('Data')
